#!/usr/bin/perl -w -i
$|++;

### Name:    unary_generate.pl

### Author:  Dougas Sweetser
###          sweetser@alum.mit.edu

### Licence: see GPL license at end


### Program description

my $function_type = "zero";

my $help_string = <<HELP;

Generates .c source files  man documentation for STDIN,
command line or file "$function_type.list", listing names of quaternion
$function_type functions in the q_lib.c library.

usage: $function_type _generate.pl [-man] [-functions_file name] [list of functions]

-man makes man file.  Takes an optional number for man directory.
Only libraries get 3, all others are 1. See man man.

Default function file name: $function_type.list.

HELP


### Libraries

use strict;
use English;
use Getopt::Long;
   $Getopt::Long::autoabbrev = 1;
   $Getopt::Long::ignorecase = 0;
use Cwd;


### Variables

my $functions_file = "$function_type.list";
my ($program, @programs);
my $function;
my $c_template = "";
my $man_template = "";
my $c_template_file = "$function_type.c.template"; 
my $docbook_template_file = "$function_type.docbook.template"; 
my ($cwd, $cwd_parent);

my $man;
my $line;

my $help;
my $QA = 1;


### Main

__get_data();

# Cycle
foreach $program (@programs)
{
    # Get program names
    $program =~ s/.c$//;
    next() unless ($program);
    ($function) = $program =~ /q_(.*)/;

    # Setup templates for inline text replacement.
    @ARGV = ();

    system ("cp $c_template_file ../src/$program.c");
    system ("cp $docbook_template_file ../Docbook/$program.docbook");
    push @ARGV, "$cwd_parent/src/$program.c", "$cwd_parent/Docbook/$program.docbook";

    # Loop through and replace text.
    while (<>)
    {
      $line = $_;
      $line =~ s/PROGRAM/$program/g;
      print $line;
    }
 
    # Create man files.
    system ("/usr/bin/docbook2man -o $cwd_parent/MAN ../Docbook/$program.docbook") if ($man);
}


### Signals

exit (0);


### Subroutines

# Get data, assign to variables.
sub __get_data {

    my $get;

    $get = GetOptions("man:i" => \$man, "functions_file=s" => \$functions_file, "help" => \$help);
  
    die ("check options please.\nProgram exiting.\n") unless $get;

    if ($help) {
        print $help_string;
        exit(1);
    }

    # Make man 1 if no integer is supplied.
    $man++ if (defined ($man) && ($man eq "0"));

    # Put info from $functions_file or STDIN to @ARGV.
    unless ($ARGV[0])
    {

        if (-e "$functions_file")
        {
            open (PROGRAMS, "<$functions_file");
            while (<PROGRAMS>)
            {
                chomp;
                $line = $_;
                @programs = split /\s+/, $line;       
                push @ARGV, @programs;
            }
        }
        else
        {
            # Put info from STDIN to @ARGV.
            print STDERR "Waiting for STDIN, ^d to exit...";

            while (<STDIN>)
            {
                chomp;
                push @ARGV, $_;
            }
        }
    }

    if (!$ARGV[0]) {
        print "\n$help_string";
        exit(1);
    }

    @programs = @ARGV;

    print STDERR "programs: @programs\n" if $QA;

    $cwd = cwd();
    ($cwd_parent) = $cwd =~ /(.*)\/\w+/;
}


### Perldoc

=pod

=head1 NAME 

unary_generate.pl -  generates .c, .docbook, man files

=head1 DESCRIPTION

Given names of quaternion functions, generates command line functions, docbook, and man documentation.

=head1 USAGE

unary_generate.pl [-man [1]] [-function_file name] [f1 f2 f3]

=head1 OPTIONS

=item I<-man>

Creates program.1 man file in current directory.

=item I<-function_file>

Name of functions of files in q_lib.c.

=item I<-help>

Prints help message.

=cut


### License
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, version 2 of the License.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
