/*      qn_asinh.c

Task:	Read in 2 quaternions (8 doubles) and 1 integer from stdin or
        the command line. Runs a unary function, qn_asinh, from q_lib.c
        on the first quaternion.  Prints result to STDOUT.
        Takes n steps to the secon quaternion, printing to STDOUT
        along the way.

Author: Douglas B Sweetser, Sweetser@alum.mit.edu.

Copyright 2002 Douglas B Sweetser.

Compiled with: gcc -Wall -o qn_asinh qn_asinh.c q_lib.c -lm

See GPL license info at the end of this file.
*/


/* Includes */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "q_lib.h"

int main (int argc, char *argv[])
{
  /* Variables */
  int n_steps, i;
  int current_arg = 1;
  double scale, q1[4], q2[4], q_step[4], q_out[4];


  /* Data input */
  while (get_q1_q2_i (&current_arg, argc, argv, q1, q2, &n_steps) ) 
    {
      /* Action */
      q_sub (q2, q1, q_out);
      scale = 1.0/( (double) n_steps - 1.0);
      q_x_scalar (q_out, scale, q_step);

      /* Take n steps. */
      for (i = 0; i < n_steps; i++)
        {
          /* Use unary operator. */
          q_asinh (q1, q_out);

          /* Data output */
          q_print (q_out);

          /* Take another step. */
          q_add (q1, q_step, q2);
          q_copy (q2, q1);
        }
    }


  /* Signals */
  return 0;
}


/*  License

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
