#!/usr/local/bin/perl5 -w
#
# test_all
#
# task:  Test command line quaternion programs
#
# author: Douglas B Sweetser <sweetser@theworld.com
#
# copywrite: 2002 Doublas B Sweetser
#
# licence: see GPL license info at the end of this file

### libraries
use strict;

### variables
my ($program, $inv, @programs);


### main

print STDOUT "1. create quaternions functions\n";
@programs = qw (q_zero q_one q_random_01 q_random_011 q_random_11);

foreach $program (@programs)
{
  print STDOUT "\ntesting $program:\n";
  print STDOUT `$program`;
}


print STDOUT "\n\n2. unary functions\n5 0 0 0, 0 5 0 0, 1 2 1 2\n";
@programs = qw (q_scalar q_vector q_abs q_norm q_norm_vector q_det q_tau_squared q_identity q_copy q_dup q_conj q_conj_1 q_conj_2 q_inv q_adj q_sin q_cos q_tan q_asin q_acos q_atan q_sinh q_cosh q_tanh q_asinh q_acosh q_atanh q_exp q_ln);

foreach $program (@programs)
{
  print STDOUT "\ntesting $program:\n";
  print STDOUT `$program 5 0 0 0`;
  print STDOUT `$program 0 5 0 0`;
  print STDOUT `$program 1 2 1 2`;
}


print STDOUT "\n\n3. binary functions\n1 2 1 2 and  2 1 2 1\n";
@programs = qw (q_add q_sub q_x q_x_even q_x_odd q_x_inv);

foreach $program (@programs)
{
  print STDOUT "\ntesting $program:\n";
  print STDOUT `$program 1 2 1 2 2 1 2 1`;
}


print STDOUT "\n\n4. binary functions given a quaternion + a scalar\n1 2 1 2 and 5\n";
@programs = qw (q_add_scalar q_x_scalar);

foreach $program (@programs)
{
  print STDOUT "\ntesting $program:\n";
  print STDOUT `$program 1 2 1 2 5`;
}


print STDOUT "\n\n5. Test anti-automorphic uniary functions\n";
@programs = qw (q_inv q_conj q_conj_1 q_conj_2);

while (@programs)
{
  $program = shift @programs;
  print STDOUT "\ntesting $program | $program:\n";
  print STDOUT `$program 1 2 1 2 | $program`;
}


print STDOUT "\n\n6. Test inverse pairs of uniary functions\n";
@programs = qw (q_sin q_asin q_cos q_acos q_tan q_atan q_sinh q_asinh q_cosh q_acosh q_tanh q_atanh q_exp q_ln);

while (@programs)
{
  $program = shift @programs;
  $inv = shift @programs;
  print STDOUT "\ntesting  $program | $inv:\n";
  print STDOUT `$program 1 2 1 2 | $inv`;
}


### signals
exit (0);


### license
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, version 2 of the License.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
